/*
**    CREADRPK.SQL
**
**    Add a primary key constraint to every table.
**
**    If this is a rerun, that is the constraint already exists, you must 
**    drop both the constraint and the underlying index, and you must 
**    drop them in that order.
*/


PRINT 'Begin CREADRPK.SQL'
GO

USE Credit
SET NOCOUNT ON
GO
IF ( (SELECT db_name()) <> 'Credit')
BEGIN
   RAISERROR ('Database "Credit" not found.',22,127) WITH LOG
END
GO


SELECT 'began' = getdate() INTO #starttime
GO



/*
**    The region table.
*/

IF EXISTS (SELECT name FROM sysobjects WHERE name = 'region_ident')
  ALTER TABLE region
    DROP CONSTRAINT region_ident

IF EXISTS (SELECT name FROM sysindexes WHERE name = 'region_ident')
    DROP INDEX  region.region_ident

ALTER TABLE region
  ADD CONSTRAINT region_ident PRIMARY KEY CLUSTERED (region_no)
GO

  
/*
**    The provider table.
*/

IF EXISTS (SELECT name FROM sysobjects WHERE name = 'provider_ident')
  ALTER TABLE provider
    DROP CONSTRAINT provider_ident

IF EXISTS (SELECT name FROM sysindexes WHERE name = 'provider_ident')
    DROP INDEX  provider.provider_ident

ALTER TABLE provider
  ADD CONSTRAINT provider_ident PRIMARY KEY CLUSTERED (provider_no)
GO

  
/*
**    The corporation table.
*/

IF EXISTS (SELECT name FROM sysobjects WHERE name = 'corporation_ident')
  ALTER TABLE corporation
    DROP CONSTRAINT corporation_ident

IF EXISTS (SELECT name FROM sysindexes WHERE name = 'corporation_ident')
    DROP INDEX  corporation.corporation_ident

ALTER TABLE corporation
  ADD CONSTRAINT corporation_ident PRIMARY KEY CLUSTERED (corp_no)
GO

  
/*
**    The member table.
*/

IF EXISTS (SELECT name FROM sysobjects WHERE name = 'member_ident')
  ALTER TABLE member
    DROP CONSTRAINT member_ident

IF EXISTS (SELECT name FROM sysindexes WHERE name = 'member_ident')
    DROP INDEX  member.member_ident

ALTER TABLE member
  ADD CONSTRAINT member_ident PRIMARY KEY CLUSTERED (member_no)
GO

  
/*
**    The statement table.
*/

IF EXISTS (SELECT name FROM sysobjects WHERE name = 'statement_ident')
  ALTER TABLE statement
    DROP CONSTRAINT statement_ident

IF EXISTS (SELECT name FROM sysindexes WHERE name = 'statement_ident')
    DROP INDEX  statement.statement_ident

ALTER TABLE statement
  ADD CONSTRAINT statement_ident PRIMARY KEY CLUSTERED (statement_no)
GO

  
/*
**    The payment table.
*/

IF EXISTS (SELECT name FROM sysobjects WHERE name = 'payment_ident')
  ALTER TABLE payment
    DROP CONSTRAINT payment_ident

IF EXISTS (SELECT name FROM sysindexes WHERE name = 'payment_ident')
    DROP INDEX  payment.payment_ident

ALTER TABLE payment
  ADD CONSTRAINT payment_ident PRIMARY KEY CLUSTERED (payment_no)
GO

  
/*
**    The charge table.
*/

IF EXISTS (SELECT name FROM sysobjects WHERE name = 'charge_ident')
  ALTER TABLE charge
    DROP CONSTRAINT charge_ident

IF EXISTS (SELECT name FROM sysindexes WHERE name = 'charge_ident')
    DROP INDEX  charge.charge_ident

ALTER TABLE charge
  ADD CONSTRAINT charge_ident PRIMARY KEY CLUSTERED (charge_no)
GO

  
/*
**    The category table.
*/

IF EXISTS (SELECT name FROM sysobjects WHERE name = 'category_ident')
  ALTER TABLE category
    DROP CONSTRAINT category_ident

IF EXISTS (SELECT name FROM sysindexes WHERE name = 'category_ident')
    DROP INDEX  category.category_ident

ALTER TABLE category
  ADD CONSTRAINT category_ident PRIMARY KEY CLUSTERED (category_no)
GO


DECLARE 
  @message char(255), 
  @began datetime  
SELECT @began = began from #starttime
SELECT ' ' = ' '
SELECT @message = 
  'Time (in minutes:seconds) to CREATE PRIMARY KEY INDEXES ' + 
  convert( char(2), datediff(ss,@began,getdate())/60 ) + 
  ':' + 
   convert( char(2), datediff(ss,@began,getdate())%60 )    
RAISERROR(@message, 10, 1)
SELECT ' ' = ' '
GO
